==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/outputs/GetManagedClusterServiceResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * The service resource.
 * @property id Azure resource identifier.
 * @property location Resource location depends on the parent resource.
 * @property name Azure resource name.
 * @property properties The service resource properties.
 * @property systemData Metadata pertaining to creation and last modification of the resource.
 * @property tags Azure resource tags.
 * @property type Azure resource type.
 */
public data class GetManagedClusterServiceResult(
    public val id: String,
    public val location: String? = null,
    public val name: String,
    public val properties:
    Either<StatefulServicePropertiesResponse, StatelessServicePropertiesResponse>,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.servicefabric.outputs.GetManagedClusterServiceResult):
            GetManagedClusterServiceResult = GetManagedClusterServiceResult(
            id = javaType.id(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            properties = javaType.properties().transform(
                { args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.servicefabric.kotlin.outputs.StatefulServicePropertiesResponse.Companion.toKotlin(args0)
                    })
                },
                { args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.servicefabric.kotlin.outputs.StatelessServicePropertiesResponse.Companion.toKotlin(args0)
                    })
                },
            ),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.servicefabric.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/servicefabric/kotlin/outputs/GetManagedClusterServiceResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabric.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * The service resource.
 * @property id Azure resource identifier.
 * @property location Resource location depends on the parent resource.
 * @property name Azure resource name.
 * @property properties The service resource properties.
 * @property systemData Metadata pertaining to creation and last modification of the resource.
 * @property tags Azure resource tags.
 * @property type Azure resource type.
 */
public data class GetManagedClusterServiceResult(
    public val id: String,
    public val location: String? = null,
    public val name: String,
    public val properties: Either<StatefulServicePropertiesResponse, StatelessServicePropertiesResponse>,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.servicefabric.outputs.GetManagedClusterServiceResult): GetManagedClusterServiceResult = GetManagedClusterServiceResult(
            id = javaType.id(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            properties = javaType.properties().transform(
                { args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.servicefabric.kotlin.outputs.StatefulServicePropertiesResponse.Companion.toKotlin(args0)
                    })
                },
                { args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.servicefabric.kotlin.outputs.StatelessServicePropertiesResponse.Companion.toKotlin(args0)
                    })
                },
            ),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.servicefabric.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
